# remirepo spec file for php-xz
#
# Copyright (c) 2021-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%{?scl:%scl_package  php-xz}

%bcond_without      tests

%global gh_commit   be72e636dd7dd8a220cb9b54f2970477dad878a0
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner    codemasher
%global gh_project  php-ext-xz
%global pecl_name   xz
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name    40-%{pecl_name}.ini
%global sources     %{gh_project}-%{gh_commit}
%global _configure  ../%{sources}/configure

Summary:       XZ (LZMA2) compression/decompression
Name:          %{?scl_prefix}php-%{pecl_name}
Version:       1.1.2
Release:       3%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:       PHP-3.01
URL:           https://github.com/%{gh_owner}/%{gh_project}
Source0:       https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{gh_project}-%{version}-%{gh_short}.tar.gz

BuildRequires: make
BuildRequires: %{?dtsprefix}gcc
BuildRequires: %{?scl_prefix}php-devel >= 7.0
BuildRequires: pkgconfig(liblzma)

Requires:      %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:      %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}


%description
PHP Extension providing XZ (LZMA2) compression/decompression functions.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc

cd %{sources}
mv LICENSE.txt LICENSE

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_XZ_VERSION/{s/.* "//;s/".*$//;p}' php_xz.h)
if test "x${extver}" != "x%{version}%{?gh_date:-dev}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?gh_date:-dev}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Drop in the bit of configuration
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension = %{pecl_name}.so

; Configuration
;xz.compression_level = 5
;xz.max_memory = 0
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}

cd ../NTS
%configure \
    --with-php-config=%{__phpconfig} \
    --with-libdir=%{_lib} \
    --with-xz
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%configure \
    --with-php-config=%{__ztsphpconfig} \
    --with-libdir=%{_lib} \
    --with-xz
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

# Install the NTS stuff
make -C NTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

%if %{with_zts}
# Install the ZTS stuff
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif



%check
cd %{sources}

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php  -q -x --offline --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite  for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php  -q -x --offline --show-diff
%endif
%endif


%files
%{!?_licensedir:%global license %%doc}
%license %{sources}/LICENSE
%doc %{sources}/README.md

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Mon Sep  4 2023 Remi Collet <remi@remirepo.net> - 1.1.2-3
- build out of sources tree

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 1.1.2-2
- rebuild for 8.1.0RC1

* Mon Aug  2 2021 Remi Collet <remi@remirepo.net> - 1.1.2-1
- update to 1.1.2
- drop all patches merged upstream

* Fri Jul  9 2021 Remi Collet <remi@remirepo.net> - 1.1.1-1
- new package, version 1.1.1
- open https://github.com/codemasher/php-ext-xz/pull/1 library check
- open https://github.com/codemasher/php-ext-xz/pull/2 ext version
- open https://github.com/codemasher/php-ext-xz/pull/3 arginfo
